@@ -48,9 +48,9 @@ class MadymoData:
         # extract matching ids
         id_strings = [(signal, ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip())
                       for signal in node.keys() if signal.startswith("SIGNAL")]
-
-        sig_id_dir = [(signal, id_.split(" ")[0]) for signal, id_ in id_strings]
-
+        print(id_strings)
+        sig_id_dir = [(signal, id_.split(" ")[0]) for signal, id_ in id_strings if "slip at" in id_]
+        print(sig_id_dir)
         for sig, id_ in sig_id_dir:
             id_idx = self._d[data_type]["slipring_ids"].index(id_)
             self._d[data_type]["ring_slip"][:, id_idx] = node[sig]["Y_VALUES"][0, :]
@@ -246,6 +246,13 @@ class MadymoData:
 
         """
         signals = [signal for signal in node.keys() if signal.startswith("SIGNAL")]
+
+        ids_name = "ids"
+        if sbtout is "slipring":
+            ids_name = "slipring_ids"
+        if sbtout is "belt":
+            ids_name = "belt_ids"
+
         for signal in signals:
             id_string = ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip()
             if data_type == "rcforc" or data_type == "secforc":
@@ -255,12 +262,6 @@ class MadymoData:
             else:
                 simplified_id = id_string.split(" ")[0]
 
-            ids_name = "ids"
-            if sbtout is "slipring":
-                ids_name = "slipring_ids"
-            if sbtout is "belt":
-                ids_name = "belt_ids"
-
             # assert (simiplified_id not in self._d[data_type][ids_name])
             # if assert: ID is already in id list
             if simplified_id in self._d[data_type][ids_name]:
@@ -268,6 +269,8 @@ class MadymoData:
             self._d[data_type][ids_name].append(simplified_id)
             self._d[data_type]["legend_ids"].append(id_string)
 
+        return
+
     def _add_time(self, node, data_type):
         """add time
 
@@ -347,16 +350,16 @@ class MadymoData:
                     elif data_type == DataChannelTypesNodout.RX_VELOCITY or \
                             data_type == DataChannelTypesNodout.RY_VELOCITY or \
                             data_type == DataChannelTypesNodout.RZ_VELOCITY:
-                        idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_VELOCITY else (
-                            1 if data_type == DataChannelTypesNodout.RY_VELOCITY else 2)
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.RX_VELOCITY else (
+                            2 if data_type == DataChannelTypesNodout.RY_VELOCITY else 3)
                         self._extratct_data(f["MODEL_0/Angular velocities"], "nodout",
                                             data_type, idx_madymo_data=idx_madymo_data)
 
                     elif data_type == DataChannelTypesNodout.RX_ACCELERATION or \
                             data_type == DataChannelTypesNodout.RY_ACCELERATION or \
                             data_type == DataChannelTypesNodout.RZ_ACCELERATION:
-                        idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (
-                            1 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 2)
+                        idx_madymo_data = 1 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (
+                            2 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 3)
                         self._extratct_data(f["MODEL_0/Angular accelerations"], "nodout", data_type,
                                             idx_madymo_data=idx_madymo_data)
 
