@@ -69,6 +69,27 @@ class VPSData:
                 path = "/CSMEXPL/multistate/TIMESERIES1/multientityresults/MODEL/TIME/ZONE1_set1/erfblock/res"
                 return (f[path][()][:, 0, 0])
 
+        elif args[1] == "legend":
+            with h5py.File(self._vps_file_path, 'r') as f:
+
+                if args[0] == VPSDataConstant.SECFORC:
+                    legend = f["/CSMEXPL/constant/attributes/SECTION/erfblock/title"][()]
+
+                elif args[0] == VPSDataConstant.NODOUT:
+                    legend = f["/CSMEXPL/constant/attributes/NODE/erfblock/title"][()]
+
+                elif args[0] == VPSDataConstant.RCFORC:
+                    legend = f["/CSMEXPL/constant/attributes/CONTACT/erfblock/title"][()]
+
+                elif args[0] == VPSDataConstant.MATSUM:
+                    legend = f["/CSMEXPL/constant/attributes/PART/erfblock/title"][()]
+                else:
+                    assert False
+
+                assert (all([len(i) <= 80 for i in legend]))
+                leg = "".join([i.decode("utf-8").ljust(80) for i in legend])
+                return leg
+
         elif args[1] == "ids":
 
             # check if data has been cached
@@ -93,17 +114,6 @@ class VPSData:
                     entid_translation = f["/CSMEXPL/constant/identifiers/NODE/erfblock/entid"][()]
                     uids = f["/CSMEXPL/constant/identifiers/NODE/erfblock/uid"][()]
 
-                    # might be a help for debugging
-
-                    # entids = np.genfromtxt(r"01_const_attributes_entid.txt", dtype=np.int)
-                    # entid_translation = np.genfromtxt(r"03_const_identifiers_node_entid.txt", dtype=np.int)
-                    # uids = np.genfromtxt(r"04_const_identifiers_node_uid.txt", dtype=np.int)
-                    #
-                    # import csv
-                    # with open(r"02_const_attributes_title.txt", newline='') as f:
-                    #     reader = csv.reader(f)
-                    #     title = list(reader)
-
                 elif args[0] == VPSDataConstant.MATSUM:
                     entids = f["/CSMEXPL/constant/attributes/PART/erfblock/entid"][()]
                     entid_translation = f["/CSMEXPL/constant/identifiers/PART/erfblock/entid"][()]
@@ -408,7 +418,7 @@ class VPSData:
 
         """
         if VPSDataConstant.NODOUT not in self._d.keys():
-            self._d[VPSDataConstant.NODOUT] = ["ids", "time"]
+            self._d[VPSDataConstant.NODOUT] = ["ids", "time", "legend"]
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
         # TODO
         if node.parent.name.split("/")[idx_of_data] == VPSDataConstant.COORDINATE:
@@ -450,7 +460,7 @@ class VPSData:
 
         """
         if VPSDataConstant.RCFORC not in self._d.keys():
-            self._d[VPSDataConstant.RCFORC] = ["ids", "time"]
+            self._d[VPSDataConstant.RCFORC] = ["ids", "time", "legend"]
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
 
         if node.parent.name.split("/")[idx_of_data] == VPSDataConstant.CONTACT_FORCE:
@@ -501,7 +511,7 @@ class VPSData:
 
         """
         if VPSDataConstant.MATSUM not in self._d.keys():
-            self._d[VPSDataConstant.MATSUM] = ["ids", "time"]
+            self._d[VPSDataConstant.MATSUM] = ["ids", "time", "legend"]
 
         idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
 
@@ -530,7 +540,7 @@ class VPSData:
         """
         if node.parent.name.split("/")[5] == VPSDataConstant.SECTION:
             if VPSDataConstant.SECFORC not in self._d.keys():
-                self._d[VPSDataConstant.SECFORC] = ["ids", "time"]
+                self._d[VPSDataConstant.SECFORC] = ["ids", "time", "legend"]
             idx_of_data = node.parent.name.split("/").index(node.parent.name.split("/")[5]) + 1
             # #         # TODO
             #         print("*******************************************")
